@@ -3,8 +3,10 @@ import sys
 import time
 from PySide.QtCore import *
 from PySide.QtGui import *
+from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5ListPickSelector
 
 # Some global variables
+GnGeoGuiVersion = "0.0.5-7"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -69,6 +71,14 @@ class Ui_MainWindow(QMainWindow):
 	AboutGnGeo = "Using " + AboutGnGeo.replace('\n','<br>')
 	# Load config
         self.options = parse_config(self,GnGeo_CfgFile)
+	AllGnGeoOpts = [ "68kclock", "autoframeskip", "biospath", "country", "effect", "fullscreen", "hwsurface", 
+	                 "interpolation", "joystick", "p1joy", "p1joydev", "p2key", "p2joy", "p2joydev", "p2key", "raster", 
+	                 "romrcdir", "samplerate", "scale", "showfps", "sleepidle", "sund", "system", "z80clock" ]
+	for GnGeoOpt in AllGnGeoOpts:
+		try:
+			 self.options[GnGeoOpt]
+		except: 
+			QMessageBox.critical(self, "Warning",  "Cannot find variable " + GnGeoOpt + " in " + GnGeo_CfgFile)
 	myPaths = [ "rompath", "biospath", "romrcdir" ]
 	for myPath in myPaths:
 		if not os.path.isdir(self.options[myPath]):
@@ -227,11 +237,11 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui 0.0.5-6</h3><p>" \
+	AboutTxt = "<h3>Gngeo-gui " + GnGeoGuiVersion + "</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
-                   "<p>GnGeo-gui is written in PySide by <i>Arno Dekker</i> 2011<p>"
+                   "<p>GnGeo-gui is written in PySide by <i>Arno Dekker</i> 2011-12<p>" %dict()
 	AboutTxt = AboutTxt + AboutGnGeo
         self.label.setText(AboutTxt)
 	self.label.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
@@ -249,7 +259,7 @@ class ConfigWindow(QMainWindow):
 	wg = QWidget()
 	area.setWidget(wg)
 	self.setCentralWidget(area)
-	wg.resize(790,660);
+	wg.resize(790,640);
 	grid = QGridLayout(wg)
 	wg.show()
 	area.show()
@@ -322,93 +332,122 @@ class ConfigWindow(QMainWindow):
 	if self.options["joystick"] == "true":
 		self.joystickPushButton.setChecked(True)
 	# system
-	grid.addWidget(QLabel("<center>system:</center>"), 4, 1)
-        self.comboSystem = QComboBox(self)
-        grid.addWidget(self.comboSystem,5,1)
+	self.systemButton = QMaemo5ValueButton("system")
+        self.systemButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+	model = QStandardItemModel(0,0) # (rows, columns)
 	systems = self.listDefaultFirst("system",['arcade','home','unibios'])
 	for sysType in systems:
-			if sysType == 'unibios':
-				if os.path.exists(self.options["biospath"] + "/uni-bios.rom"):
-       			 		self.comboSystem.addItem('unibios')
-			else:
-	       		 	self.comboSystem.addItem(sysType)
+		if sysType == 'unibios':
+			if os.path.exists(self.options["biospath"] + "/uni-bios.rom"):
+				model.appendRow(QStandardItem("unibios"))
+		else:
+       		 	model.appendRow(QStandardItem(sysType))
+	lps = QMaemo5ListPickSelector()
+	lps.setModel(model)
+	lps.setCurrentIndex(0)
+        #and list selector to button
+        self.systemButton.setPickSelector(lps)
+        grid.addWidget(self.systemButton,4,1)
+
 	# country
-	grid.addWidget(QLabel("<center>region:</center>"), 4, 2)
-        self.comboCountry = QComboBox(self)
-        grid.addWidget(self.comboCountry,5,2)
+	self.regionButton = QMaemo5ValueButton("region")
+        self.regionButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+	modelc = QStandardItemModel(0,0) # (rows, columns)
 	countries = self.listDefaultFirst("country",['japan', 'usa', 'europe'])
 	for Location in countries:
-       		 	self.comboCountry.addItem(Location)
+		modelc.appendRow(QStandardItem(Location))
+	lpc = QMaemo5ListPickSelector()
+	lpc.setModel(modelc)
+	lpc.setCurrentIndex(0)
+        self.regionButton.setPickSelector(lpc)
+        grid.addWidget(self.regionButton,4,2)
 	# effect
-	grid.addWidget(QLabel("<center>effect:</center>"), 4, 3)
-        self.comboEffect = QComboBox(self)
-        grid.addWidget(self.comboEffect,5,3)
-	effects = self.listDefaultFirst("effect",['none', 'scanline', 'scanline50', 'scale2x', 'scale3x', 'scale4x', 'scale2x50', 'scale2x75', 'hq2x', 'hq3x', 'lq2x', 'lq3x', 'doublex'])
+	self.effectButton = QMaemo5ValueButton("effect")
+        self.effectButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+	modele = QStandardItemModel(0,0) # (rows, columns)
+	effects = self.listDefaultFirst("effect",['none', 'scanline', 'scanline50', 'scale2x',
+	                                          'scale3x', 'scale4x', 'scale2x50', 'scale2x75',
+	                                          'hq2x', 'hq3x', 'lq2x', 'lq3x', 'doublex'])
 	for effect in effects:
-		self.comboEffect.addItem(effect)
+		modele.appendRow(QStandardItem(effect))
+	lpe = QMaemo5ListPickSelector()
+	lpe.setModel(modele)
+	lpe.setCurrentIndex(0)
+        self.effectButton.setPickSelector(lpe)
+        grid.addWidget(self.effectButton,4,3)
 	# Samplerate
-	grid.addWidget(QLabel("<center>sound rate:</center>"), 6, 1)
+	grid.addWidget(QLabel("<center>sound rate:</center>"), 5, 1)
         self.comboSampleRate = QComboBox(self)
-        grid.addWidget(self.comboSampleRate,7,1)
+        grid.addWidget(self.comboSampleRate,6,1)
 	Sam_Rates = self.listDefaultFirst("samplerate",['8192','11025','22050','32000','44100','48000'])
 	for SampRate in Sam_Rates:
 		self.comboSampleRate.addItem(SampRate)
 	# Z80 CPU clock
-	grid.addWidget(QLabel("<center>Z80 CPU clock:</center>"), 6, 2)
+	grid.addWidget(QLabel("<center>Z80 CPU clock:</center>"), 5, 2)
 	self.Z80SpinBox = QDoubleSpinBox()
 	self.Z80SpinBox.setRange(-80,80)
 	self.Z80SpinBox.setAlignment(Qt.AlignCenter)
 	self.Z80SpinBox.setValue(float(self.options["z80clock"]))
 	self.Z80SpinBox.setDecimals(0)
 	self.Z80SpinBox.setSuffix(" %")
-	grid.addWidget(self.Z80SpinBox, 7,2)
+	grid.addWidget(self.Z80SpinBox, 6,2)
 	# 68K CPU clock
-	grid.addWidget(QLabel("<center>68K CPU clock:</center>"), 6, 3)
+	grid.addWidget(QLabel("<center>68K CPU clock:</center>"), 5, 3)
 	self.M68KSpinBox = QDoubleSpinBox()
 	self.M68KSpinBox.setRange(-80,80)
 	self.M68KSpinBox.setAlignment(Qt.AlignCenter)
 	self.M68KSpinBox.setValue(float(self.options["68kclock"]))
 	self.M68KSpinBox.setDecimals(0)
 	self.M68KSpinBox.setSuffix(" %")
-	grid.addWidget(self.M68KSpinBox, 7,3)
+	grid.addWidget(self.M68KSpinBox, 6,3)
 	# Joystick device P1 (/dev/input/js?)
-	grid.addWidget(QLabel("<center>P1 joystick device:</center>"), 8,1)
-        self.comboJoyp1dev = QComboBox(self)
-        grid.addWidget(self.comboJoyp1dev,9,1)
+	self.joyp1devButton = QMaemo5ValueButton("P1 joystick device")
+        self.joyp1devButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+	modelp1dev = QStandardItemModel(0,0) # (rows, columns)
 	JoyP1devs = self.listDefaultFirst("p1joydev",['0', '1', '2', '3'])
 	for JoyP1dev in JoyP1devs:
-       		self.comboJoyp1dev.addItem(JoyP1dev)
+		modelp1dev.appendRow(QStandardItem(JoyP1dev))
+	lpjp1 = QMaemo5ListPickSelector()
+	lpjp1.setModel(modelp1dev)
+	lpjp1.setCurrentIndex(0)
+        self.joyp1devButton.setPickSelector(lpjp1)
+        grid.addWidget(self.joyp1devButton,7,1)
 	# Joystick device P2 (/dev/input/js?)
-	grid.addWidget(QLabel("<center>P2 joystick device:</center>"), 8,2)
-        self.comboJoyp2dev = QComboBox(self)
-        grid.addWidget(self.comboJoyp2dev,9,2)
+	self.joyp2devButton = QMaemo5ValueButton("P2 joystick device")
+        self.joyp2devButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+	modelp2dev = QStandardItemModel(0,0) # (rows, columns)
 	JoyP2devs = self.listDefaultFirst("p2joydev",['0', '1', '2', '3'])
 	for JoyP2dev in JoyP2devs:
-       		self.comboJoyp2dev.addItem(JoyP2dev)
+		modelp2dev.appendRow(QStandardItem(JoyP2dev))
+	lpjp2 = QMaemo5ListPickSelector()
+	lpjp2.setModel(modelp2dev)
+	lpjp2.setCurrentIndex(0)
+        self.joyp2devButton.setPickSelector(lpjp2)
+        grid.addWidget(self.joyp2devButton,7,2)
         # Exit on start button
         self.exitPushButton = QPushButton("exit after start game",self)
 	self.exitPushButton.setCheckable(True)
-        grid.addWidget(self.exitPushButton,9,3)
+        grid.addWidget(self.exitPushButton,7,3)
 	if self.gui_opts["exit_after_launch"] == "true":
 		self.exitPushButton.setChecked(True)
 	# Path button
         self.pathButton = QPushButton("paths def",self)
         self.pathButton.setFont(font)
-        grid.addWidget(self.pathButton,10,1)
+        grid.addWidget(self.pathButton,8,1)
 	QObject.connect(self.pathButton
 		, SIGNAL("clicked()")
 		, self.on_paths_clicked)
 	# Keys button
         self.keysButton = QPushButton("key def",self)
         self.keysButton.setFont(font)
-        grid.addWidget(self.keysButton,10,2)
+        grid.addWidget(self.keysButton,8,2)
 	QObject.connect(self.keysButton
 		, SIGNAL("clicked()")
 		, self.on_keys_clicked)
 	# Joystick config
         self.joyconfButton = QPushButton("joystick def",self)
         self.joyconfButton.setFont(font)
-        grid.addWidget(self.joyconfButton,10,3)
+        grid.addWidget(self.joyconfButton,8,3)
 	QObject.connect(self.joyconfButton
 		, SIGNAL("clicked()")
 		, self.on_defjoy_clicked)
@@ -418,7 +457,7 @@ class ConfigWindow(QMainWindow):
 	"QPushButton { color: red; font:bold; }"
       		) 
         self.saveButton.setFont(font)
-        grid.addWidget(self.saveButton,12,1,1,3)
+        grid.addWidget(self.saveButton,9,1,1,3)
 	QObject.connect(self.saveButton
 		, SIGNAL("clicked()")
 		, self.on_save_clicked)
@@ -457,12 +496,12 @@ class ConfigWindow(QMainWindow):
         else: doExit = "false" 
 	self.options["68kclock"] = "%.0f" % self.M68KSpinBox.value()
 	self.options["z80clock"] = "%.0f" % self.Z80SpinBox.value()
-	self.options["system"] = self.comboSystem.currentText()
-	self.options["country"] = self.comboCountry.currentText()
-	self.options["effect"] = self.comboEffect.currentText()
+	self.options["system"] = self.systemButton.valueText()
+	self.options["country"] = self.regionButton.valueText()
+	self.options["effect"] = self.effectButton.valueText()
 	self.options["samplerate"] = self.comboSampleRate.currentText()
-	self.options["p1joydev"] = self.comboJoyp1dev.currentText()
-	self.options["p2joydev"] = self.comboJoyp2dev.currentText()
+	self.options["p1joydev"] = self.joyp1devButton.valueText()
+	self.options["p2joydev"] = self.joyp2devButton.valueText()
 	if BiosPath != "":
 		self.options["biospath"] = BiosPath
 	if RomrcPath != "":
@@ -531,9 +570,9 @@ class ConfigWindow(QMainWindow):
 			for option in self.options:
 				newConfigFile.write(option + " " + self.options[option] + "\n")
 			newConfigFile.close()
-                        os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
-                        /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-                        string:"Configuration is succesfully saved"')
+			os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
+			           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
+			           string:"Configuration is succesfully saved"')
 
     def listDefaultFirst(self, optVal,List):
 	Position = List.index(self.options[optVal])
